from PyQt5 import QtWidgets
from PyQt5.QtWidgets import QApplication, QMainWindow
import sys, random

def createWindow(WINWIDTH = 1280, WINHEIGHT = 720, TITLE="Window"):
    app = QApplication(sys.argv)
    win = QMainWindow()
    win.setGeometry(random.randint(200, 1200), random.randint(200, 800), WINWIDTH, WINHEIGHT)
    win.setWindowTitle(TITLE)
    
    return {'APP': app, 'WIN': win,'WINWIDTH': WINWIDTH, 'WINHEIGHT': WINHEIGHT}

def createText(win, xpos=None, ypos=None, content="[EMPTY TEXT]"):
    if xpos == None:
        xpos = random.randint(0, win['WINWIDTH']-15)
    if ypos == None:
        ypos = random.randint(0, win['WINHEIGHT']-15)
    label = QtWidgets.QLabel(win['WIN'])
    label.setText(content)
    label.move(xpos, ypos)

def close(win):
    win['WIN'].show()
    sys.exit(win['APP'].exec_())


from setuptools import setup, find_packages
 
classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Education',
    'Operating System :: Microsoft :: Windows :: Windows 10',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3'
]
 
setup(
    name='glib',
    version='1.0.0',
    description='A python graphics library that piggy-backs off of pyqt5',
    long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
    url='',  
    author='its_me',
    author_email='rycepie3909@gmail.com',
    license='MIT', 
    classifiers=classifiers,
    keywords='graphics', 
    packages=find_packages(),
    install_requires=['']
)